import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import {FakeBackendInterceptor, fakeBackendProvider} from './helpers';
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { TopBarComponent } from './components/top-bar/top-bar.component';
import {
  MatButtonModule,
  MatCardModule,
  MatFormFieldModule,
  MatIconModule, MatInputModule,
  MatListModule,
  MatSidenavModule,
  MatToolbarModule
} from '@angular/material';
import { HomeComponent } from './pages/home/home.component';
import { LoginComponent } from './pages/login/login.component';
import { RegisterComponent } from './pages/register/register.component';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {HTTP_INTERCEPTORS, HttpClientModule} from '@angular/common/http';
import { JwtInterceptor, ErrorInterceptor } from './helpers';
import { AngularMaterialModule } from './angular-material.module';
import {UserProfileComponent} from './pages/user-profile/user-profile.component';
import { MDBBootstrapModule } from 'angular-bootstrap-md';
import {FooterComponent} from './components/footer/footer.component';
import { BuyTombstoneComponent } from './pages/buy-tombstone/buy-tombstone.component';
import { CheckTombstoneComponent } from './pages/check-tombstone/check-tombstone.component';
import { AngularFireModule } from '@angular/fire';
import { AngularFireDatabaseModule } from '@angular/fire/database';
import { environment } from '../environments/environment';
import {AngularFirestore} from '@angular/fire/firestore';
import {ModalComponent} from './components/modal/modal.component';
import {TombstoneComponent} from './pages/tombstone/tombstone.component';
import { CemeteryComponent } from './pages/cemetery/cemetery.component';

@NgModule({
  declarations: [
    AppComponent,
    TopBarComponent,
    HomeComponent,
    LoginComponent,
    RegisterComponent,
    UserProfileComponent,
    FooterComponent,
    BuyTombstoneComponent,
    CheckTombstoneComponent,
    ModalComponent,
    TombstoneComponent,
    CemeteryComponent
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    BrowserAnimationsModule,
    MatToolbarModule,
    MatIconModule,
    MatSidenavModule,
    MatListModule,
    MatButtonModule,
    ReactiveFormsModule,
    HttpClientModule,
    MatCardModule,
    MatFormFieldModule,
    MatInputModule,
    AngularMaterialModule,
    MDBBootstrapModule.forRoot (),
    AngularFireModule.initializeApp (environment.firebaseConfig),
    AngularFireDatabaseModule,
    FormsModule
  ],
  entryComponents: [ ModalComponent ],
  providers: [
    { provide: HTTP_INTERCEPTORS, useClass: JwtInterceptor, multi: true },
    { provide: HTTP_INTERCEPTORS, useClass: ErrorInterceptor, multi: true },
    fakeBackendProvider,
    AngularFirestore
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
