import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {first} from 'rxjs/operators';
import {ActivatedRoute, Router} from '@angular/router';
import {AuthenticationService} from '../../services';
import {Tombstone} from '../../model/tombstone.model';
import { TombstoneService } from '../../services/tombstone.service';

@Component({
  selector: 'app-buy-tombstone',
  templateUrl: './buy-tombstone.component.html',
  styleUrls: ['./buy-tombstone.component.scss']
})
export class BuyTombstoneComponent implements OnInit {
  loginForm: FormGroup;
  loading = false;
  submitted = false;
  returnUrl: string;
  error: string;
  success: string;
  username: string;

  constructor(
    private formBuilder: FormBuilder,
    private route: ActivatedRoute,
    private router: Router,
    private authenticationService: AuthenticationService,
    private tombstoneService: TombstoneService
  ) { }

  ngOnInit() {
    this.loginForm = this.formBuilder.group({
      size: ['', Validators.required],
      petName: ['', Validators.required],
      photoUrl: ['', Validators.required],
      description: ['', Validators.required]
    });

    this.getTombstones()

    // get return url from route parameters or default to '/'
    this.returnUrl = this.route.snapshot.queryParams['returnUrl'] || '/';

    // // show success message on registration
    // if (this.route.snapshot.queryParams['registered']) {
    //   this.success = 'Registration successful';
    // }
  }

  // convenience getter for easy access to form fields
  get f() { return this.loginForm.controls; }
  getUserName() {
    const user = localStorage.getItem('currentUser');
    const jsonValue = JSON.parse(user)
    console.log(jsonValue);
    this.username = jsonValue.username;
    return this.username
  }

  onSubmit() {
    this.submitted = true;

    // reset alerts on submit
    this.error = null;
    this.success = null;

    // stop here if form is invalid
    // if (this.loginForm.invalid) {
    //   return;
    // }

    const tombstone = new Tombstone(this.f.size.value, this.getUserName(), this.f.petName.value, this.f.photoUrl.value, this.f.description.value)
    console.log(tombstone)
    this.create(tombstone)
    this.loading = true;
    // this.authenticationService.buyTombstone(this.f.username.value, this.f.password.value, this.getUserName());
    this.router.navigate(['/user-login']);

  }

  create(tombstone: Tombstone) {
    this.tombstoneService.createTombstone(tombstone);
  }

  tombstones;

  getTombstones = () =>
    this.tombstoneService
      .getTombstones()
      .subscribe(res =>(this.tombstones = res));
}

